==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_links.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_links.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("LCLAN_1", "Options Saved");
define("LCLAN_2", "Link saved to database.");
define("LCLAN_3", "Link updated in database.");
// define("LCLAN_4", "Link deleted.");
define("LCLAN_6", "Order updated.");
define("LCLAN_8", "Existing Links");
define("LCLAN_12", "Link Rendertype");
define("LCLAN_15", "Link Name");
define("LCLAN_16", "Link URL");
define("LCLAN_17", "Link Description");
define("LCLAN_18", "Link Button / Icon");
define("LCLAN_19", "Link Open Type");
define("LCLAN_20", "Opens in same window");
define("LCLAN_23", "Opens in new window");
define("LCLAN_24", "Opens in 600x400 mini-window");
define("LCLAN_25", "Link Class");
define("LCLAN_26", "Ticking will make the link visible to only users in that class");
define("LCLAN_27", "Update Link");
define("LCLAN_28", "Create link");
define("LCLAN_29", "Links");
define("LCLAN_30", "move up");
define("LCLAN_31", "move down");
define("LCLAN_39", "View Images");
define("LCLAN_53", "Link");
define("LCLAN_54", "deleted");
define("LCLAN_58", "Are you sure you want to delete this link?");
define("LCLAN_61", "No links");
define("LCLAN_62", "Links Front Page");
define("LCLAN_63", "Create New Link");
define("LCLAN_68", "Links Options");
define("LCLAN_78", "Show Description as Screen-Tip");
define("LCLAN_79", "Description will be shown when the mouse hovers over the link");
define("LCLAN_80", "Activate expanding sub-menus");
define("LCLAN_81", "Sub-menus will display only after clicking their parent. (Link parent is disabled)");
define("LCLAN_83", "Submenus Generator");
define("LCLAN_88", "Site Links Options");
define("LCLAN_89", "Image");

define("LCLAN_91", "Move");
define("LCLAN_95", "Class");

define("LCLAN_96", "Shown in your theme as");


define("LINKLAN_1", "Opens in 800x600 window");
define("LINKLAN_2", "Parent");
define("LINKLAN_3", "No Parent (Normal Link)");
define("LINKLAN_4", "Sublink Generator");
define("LINKLAN_5", "Generate Sublinks");
define("LINKLAN_6", "Create sublinks from:");
define("LINKLAN_7", "Create sublinks under which link?");
define("LINKLAN_8", "News Categories");
define("LINKLAN_9", "Download Categories");
define("LINKLAN_10", "Create Sublink");

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_links.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_links.php $
|     $Revision: 11678 $
|     $Id: lan_links.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("LCLAN_1", "Options Saved");
define("LCLAN_2", "Link saved to database.");
define("LCLAN_3", "Link updated in database.");
// define("LCLAN_4", "Link deleted.");
define("LCLAN_6", "Order updated.");
define("LCLAN_8", "Existing Links");
define("LCLAN_12", "Link Rendertype");
define("LCLAN_15", "Link Name");
define("LCLAN_16", "Link URL");
define("LCLAN_17", "Link Description");
define("LCLAN_18", "Link Button / Icon");
define("LCLAN_19", "Link Open Type");
define("LCLAN_20", "Opens in same window");
define("LCLAN_23", "Opens in new window");
define("LCLAN_24", "Opens in 600x400 mini-window");
define("LCLAN_25", "Link Class");
define("LCLAN_26", "Ticking will make the link visible to only users in that class");
define("LCLAN_27", "Update Link");
define("LCLAN_28", "Create link");
define("LCLAN_29", "Links");
define("LCLAN_30", "move up");
define("LCLAN_31", "move down");
define("LCLAN_39", "View Images");
define("LCLAN_53", "Link");
define("LCLAN_54", "deleted");
define("LCLAN_58", "Are you sure you want to delete this link?");
define("LCLAN_61", "No links");
define("LCLAN_62", "Links Front Page");
define("LCLAN_63", "Create New Link");
define("LCLAN_68", "Links Options");
define("LCLAN_78", "Show Description as Screen-Tip");
define("LCLAN_79", "Description will be shown when the mouse hovers over the link");
define("LCLAN_80", "Activate expanding sub-menus");
define("LCLAN_81", "Sub-menus will display only after clicking their parent. (Link parent is disabled)");
define("LCLAN_83", "Submenus Generator");
define("LCLAN_88", "Site Links Options");
define("LCLAN_89", "Image");

define("LCLAN_91", "Move");
define("LCLAN_95", "Class");

define("LCLAN_96", "Shown in your theme as");


define("LINKLAN_1", "Opens in 800x600 window");
define("LINKLAN_2", "Parent");
define("LINKLAN_3", "No Parent (Normal Link)");
define("LINKLAN_4", "Sublink Generator");
define("LINKLAN_5", "Generate Sublinks");
define("LINKLAN_6", "Create sublinks from:");
define("LINKLAN_7", "Create sublinks under which link?");
define("LINKLAN_8", "News Categories");
define("LINKLAN_9", "Download Categories");
define("LINKLAN_10", "Create Sublink");

?>
